@@ -6,7 +6,7 @@ sentry.app
 :license: BSD, see LICENSE for more details.
 """
 
-from sentry.conf import settings
+from django.conf import settings
 from sentry.utils.imports import import_string
 from threading import local
 
@@ -18,9 +18,7 @@ class State(local):
 
 def get_instance(path, options):
     cls = import_string(path)
-    if cls is None:
-        raise ImportError('Unable to find module %s' % path)
     return cls(**options)
 
-buffer = get_instance(settings.BUFFER, settings.BUFFER_OPTIONS)
+buffer = get_instance(settings.SENTRY_BUFFER, settings.SENTRY_BUFFER_OPTIONS)
 env = State()
